@@ -1,10 +1,14 @@
-"plotSplom" <-
-function(mcmc, axes=FALSE, between=0, div=1, log=FALSE, base=10, ...)
+plotSplom <- function(mcmc, axes=FALSE, between=0, div=1, log=FALSE, base=10, ...)
 {
+  ## 1  Parse args
   ellipsis <- as.list(substitute(list(...)))[-1]
-  if(is.null(dim(mcmc))) stop("Argument 'mcmc' must contain more than one chain, arranged in columns.")
+  if(is.null(dim(mcmc)))
+    stop("Argument 'mcmc' must contain more than one chain, arranged in columns.")
+
+  ## 2  Transform
   mcmc <- if(log) log(mcmc/div,base=base) else mcmc/div
 
+  ## 3  Draw plot
   if(!axes && is.null(ellipsis$oma))
     suppressWarnings(pairs(mcmc, gap=between, oma=c(0,0,0,0), xaxt="n", yaxt="n", ...))
   else
@@ -12,4 +16,3 @@ function(mcmc, axes=FALSE, between=0, div=1, log=FALSE, base=10, ...)
 
   invisible(NULL)
 }
-
